#------------------------------------------------------------------------------
# Programm         : F H i s t . p m
#------------------------------------------------------------------------------
# Autor            : Christian Dhl
# Erstellt         : 14. Februar 2003
# Zuletzt gendert : 16. Dezember 2004
# Aufgabe          : Verwaltung der letzten X bearbeiteten Dateien.
#------------------------------------------------------------------------------

package Graph::GED::FHist;

use strict;
use warnings;

#------------------------------------------------------------------------------
# Globale ffentliche Variablen:
#------------------------------------------------------------------------------
use base qw/Exporter/;
our @EXPORT_OK = qw/load save add array/;


#------------------------------------------------------------------------------
# Globale private Variablen:
#------------------------------------------------------------------------------
my $Anzahl = 10;                     # Anzahl zu merkender Dateien
my $Fname  = 'ged_last_edited.txt';  # Name der Datei, unter der
                                     # die Dateien geladen / gespeichert
                                     # werden
my @Fhist;                           # Array mit den Dateinamen

my $Debug = 0;                       # Debugausgaben in diesem Modul


sub load {
    #--------------------------------------------------------------------------
    # sub          : l o a d
    #--------------------------------------------------------------------------
    # Autor        : CD
    # Aufgabe      : Ldt die Liste mit den historischen Dateien.
    # Parameter    : text
    # Rckgabewert : text
    #--------------------------------------------------------------------------
    # 0.0.1 - 17.02.2003 - CD - Erstellt
    #--------------------------------------------------------------------------

    print "GEDfhist::load\n" if $Debug;

    @Fhist = ();

    open IN, $Fname or return;
    my $c = 0;
    while (<IN>) {
        chomp;
        push @Fhist, $_;
        ++$c;
        last if $c == $Anzahl;
    }
} # sub load


sub save {
    #--------------------------------------------------------------------------
    # sub          : s a v e
    #--------------------------------------------------------------------------
    # Autor        : CD
    # Aufgabe      : Speichert die historischen Dateien.
    # Parameter    : keine
    # Rckgabewert : keiner
    #--------------------------------------------------------------------------
    # 0.0.1 - 17.02.2003 - CD - Erstellt
    #--------------------------------------------------------------------------

    print "GEDfhist::save\n" if $Debug;
    open OUT, ">$Fname" or die "Kann Datei '$Fname' nicht zum Speichern " .
                               "ffnen: $!";
    for (1..min($Anzahl, scalar @Fhist)) {
        print OUT $Fhist[$_-1], "\n";
    }
} # sub save


sub add {
    #--------------------------------------------------------------------------
    # sub          : a d d
    #--------------------------------------------------------------------------
    # Autor        : CD
    # Aufgabe      : Fgt einen weiteren Namen in die Historie ein
    # Parameter    : Dateiname
    # Rckgabewert : keiner
    #--------------------------------------------------------------------------
    # 0.0.1 - 17.02.2003 - CD - Erstellt
    #--------------------------------------------------------------------------

    my $f = shift;
    print "GEDfhist::add - neue Datei = '$f'\n" if $Debug;

    # Nach vorhandenen gleichen Eintrgen suchen und lschen:
    for my $i (reverse (0..$#Fhist)) {
        splice(@Fhist, $i, 1) if $f eq $Fhist[$i];
    }

    # Neuen Eintrag anhngen:
    push @Fhist, $f;

    # Falls es mehr als $Anzahl sind, ersten lschen:
    splice(@Fhist, 0, 1) if scalar @Fhist > $Anzahl;
} # sub add


sub array {
    #--------------------------------------------------------------------------
    # sub          : a r r a y
    #--------------------------------------------------------------------------
    # Autor        : CD
    # Aufgabe      : Gibt ein Array mit den historischen Dateinamen aus.
    # Parameter    : keine
    # Rckgabewert : keiner
    #--------------------------------------------------------------------------
    # 0.0.1 - 17.02.2003 - CD - Erstellt
    #--------------------------------------------------------------------------

    print "GEDfhist::array\n" if $Debug;
    return @Fhist;
} # sub array


sub min {
    #--------------------------------------------------------------------------
    # sub          : m i n
    #--------------------------------------------------------------------------
    # Autor        : CD
    # Aufgabe      : Bestimmt das Minimum zweier Zahlen
    # Parameter    : zwei Zahlen
    # Rckgabewert : die kleinere Zahl
    #--------------------------------------------------------------------------
    # 0.0.1 - 17.02.2003 - CD - Erstellt
    #--------------------------------------------------------------------------

    print "GEDfhist::min\n" if $Debug;
    my $l = shift;
    my $r = shift;

    return $r if $r<$l;
    return $l;
} # sub max


sub max {
    #--------------------------------------------------------------------------
    # sub          : m a x
    #--------------------------------------------------------------------------
    # Autor        : CD
    # Aufgabe      : Bestimmt das Maximum zweier Zahlen
    # Parameter    : zwei Zahlen
    # Rckgabewert : die grere Zahl
    #--------------------------------------------------------------------------
    # 0.0.1 - 17.02.2003 - CD - Erstellt
    #--------------------------------------------------------------------------

    print "GEDfhist::max\n" if $Debug;
    my $l = shift;
    my $r = shift;

    return $r if $r>$l;
    return $l;
} # sub max


return 1;

__END__

=head1 NAME

Graphen::GED::FHist.pm - a module for a file history, used in a "file"-Menu

=head1 COPYRIGHT


Copyright 2004 Christian Duehl. All rights reserved.

This library is free software. You can redistribute it and/or
modify it under the same terms as perl itself.

=cut
